# Changelog

## v0.1.9 (2024-03-29)

* Improved support for interactively killing (KeyboardInterrupt) and rerunning endpoints, optimizing for reduced memory
  consumption and immediate results processing. ([#9](https://github.com/opendoor-labs/open-exchange-python/pull/9))
* Improved examples based on client feedback. ([#10](https://github.com/opendoor-labs/open-exchange-python/pull/10))

## v0.1.8 (2024-03-19)

* Use a "public" address in the `README.md` and our examples.

## v0.1.7 (2024-03-19)

* Initial release
